@@ -1,24 +1,7 @@
 var __defProp = Object.defineProperty;
-var __defProps = Object.defineProperties;
 var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
-var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
 var __getOwnPropNames = Object.getOwnPropertyNames;
-var __getOwnPropSymbols = Object.getOwnPropertySymbols;
 var __hasOwnProp = Object.prototype.hasOwnProperty;
-var __propIsEnum = Object.prototype.propertyIsEnumerable;
-var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
-var __spreadValues = (a, b) => {
-  for (var prop in b || (b = {}))
-    if (__hasOwnProp.call(b, prop))
-      __defNormalProp(a, prop, b[prop]);
-  if (__getOwnPropSymbols)
-    for (var prop of __getOwnPropSymbols(b)) {
-      if (__propIsEnum.call(b, prop))
-        __defNormalProp(a, prop, b[prop]);
-    }
-  return a;
-};
-var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
 var __export = (target, all) => {
   for (var name in all)
     __defProp(target, name, { get: all[name], enumerable: true });
@@ -83,9 +66,10 @@ async function handler(event) {
   try {
     const body = JSON.parse(event.body ?? "{}");
     if (!isUrlValid(body.url)) {
-      return __spreadProps(__spreadValues({}, response), {
+      return {
+        ...response,
         statusCode: 400
-      });
+      };
     }
     const update = await documentClient.update({
       TableName: getEnv("TABLE_NAME"),
@@ -108,17 +92,19 @@ async function handler(event) {
       Body: JSON.stringify({ url: body.url })
     }).promise();
     console.log("Put object: %j", putObject);
-    return __spreadProps(__spreadValues({}, response), {
+    return {
+      ...response,
       body: JSON.stringify({
         url: body.url,
         shortUrl: `https://${getEnv("DOMAIN_NAME")}/${key}`
       })
-    });
+    };
   } catch (err) {
     console.log(err);
-    return __spreadProps(__spreadValues({}, response), {
+    return {
+      ...response,
       statusCode: 500
-    });
+    };
   }
 }
 // Annotate the CommonJS export names for ESM import in node:
